import * as React from 'react';
import FullCalendar, { CalendarOptions } from '@fullcalendar/react';
import dayGridPlugin from '@fullcalendar/daygrid';
import interactionPlugin from '@fullcalendar/interaction';
import timeGridPlugin from '@fullcalendar/timegrid';

export type CalendarProps = Omit<CalendarOptions, 'plugins'>;

function CalendarWrapper(props: CalendarProps, ref: React.Ref<FullCalendar>) {
  return (
    <FullCalendar
      ref={ref}
      allDaySlot={false}
      firstDay={1}
      height="auto"
      initialView="timeGridWeek"
      plugins={[dayGridPlugin, timeGridPlugin, interactionPlugin]}
      {...props}
    />
  );
}

export const Calendar = React.forwardRef<FullCalendar, CalendarProps>(
  CalendarWrapper
);
